Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(852)

Unified Diff: chrome/browser/ui/views/balloon_collection_impl_win.h

Issue 11819048: Implement message center on Windows (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebase on master @fa1d2262 and rearrange dependencies. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/balloon_collection_impl_win.h
diff --git a/chrome/browser/ui/views/ash/balloon_collection_impl_ash.h b/chrome/browser/ui/views/balloon_collection_impl_win.h
similarity index 64%
copy from chrome/browser/ui/views/ash/balloon_collection_impl_ash.h
copy to chrome/browser/ui/views/balloon_collection_impl_win.h
index 1e2917d56347b0d37aa9c788620023bf96e87621..66fc28ad68abdd20be9b09116566a0e0940b59a4 100644
--- a/chrome/browser/ui/views/ash/balloon_collection_impl_ash.h
+++ b/chrome/browser/ui/views/balloon_collection_impl_win.h
@@ -2,23 +2,27 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_VIEWS_ASH_BALLOON_COLLECTION_IMPL_ASH_H_
-#define CHROME_BROWSER_UI_VIEWS_ASH_BALLOON_COLLECTION_IMPL_ASH_H_
+#ifndef CHROME_BROWSER_UI_VIEWS_BALLOON_COLLECTION_IMPL_WIN_H_
+#define CHROME_BROWSER_UI_VIEWS_BALLOON_COLLECTION_IMPL_WIN_H_
#include <set>
-#include "chrome/browser/chromeos/notifications/balloon_view_host_chromeos.h" // MessageCallback
#include "chrome/browser/notifications/balloon_collection_impl.h"
#include "ui/message_center/message_center.h"
+namespace extensions {
+class Extension;
+}
+
// Wrapper on top of ::BalloonCollectionImpl to provide integration between
-// the Chrome notification UI and Ash notifications (ash::WebNotificationTray).
-class BalloonCollectionImplAsh
+// the Chrome notification UI and Windows notifications
+// (ui::MessageCenterTrayHostWin).
+class BalloonCollectionImplWin
: public BalloonCollectionImpl,
public message_center::MessageCenter::Delegate {
public:
- BalloonCollectionImplAsh();
- virtual ~BalloonCollectionImplAsh();
+ BalloonCollectionImplWin();
+ virtual ~BalloonCollectionImplWin();
// Overridden from BalloonCollectionImpl.
virtual void Add(const Notification& notification,
@@ -35,16 +39,6 @@ class BalloonCollectionImplAsh
virtual void OnButtonClicked(const std::string& notification_id,
int button_index) OVERRIDE;
- // Adds a callback for WebUI message. Returns true if the callback
- // is succssfully registered, or false otherwise. It fails to add if
- // there is no notification that matches NotificationDelegate::id(),
- // or a callback for given message already exists. The callback
- // object is owned and deleted by callee.
- bool AddWebUIMessageCallback(
- const Notification& notification,
- const std::string& message,
- const chromeos::BalloonViewHost::MessageCallback& callback);
-
// Updates the notification's content. It uses
// NotificationDelegate::id() to check the equality of notifications.
// Returns true if the notification has been updated. False if
@@ -52,7 +46,7 @@ class BalloonCollectionImplAsh
// visibility of the notification.
bool UpdateNotification(const Notification& notification);
// On Ash this behaves the same as UpdateNotification.
bool UpdateAndShowNotification(const Notification& notification);
protected:
@@ -64,7 +58,7 @@ class BalloonCollectionImplAsh
const extensions::Extension* GetBalloonExtension(Balloon* balloon);
private:
- DISALLOW_COPY_AND_ASSIGN(BalloonCollectionImplAsh);
+ DISALLOW_COPY_AND_ASSIGN(BalloonCollectionImplWin);
};
-#endif // CHROME_BROWSER_UI_VIEWS_ASH_BALLOON_COLLECTION_IMPL_ASH_H_
+#endif // CHROME_BROWSER_UI_VIEWS_BALLOON_COLLECTION_IMPL_WIN_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -52,7 +46,7 @@ class BalloonCollectionImplAsh
// visibility of the notification.
bool UpdateNotification(const Notification& notification);
- // On Ash this behaves the same as UpdateNotification.
+ // On Win this behaves the same as UpdateNotification.
bool UpdateAndShowNotification(const Notification& notification);
protected: